@@ -310,7 +310,7 @@ async def test_mock_clock_autojump(mock_clock):
     mock_clock.autojump_threshold = 0
     assert mock_clock.autojump_threshold == 0
 
-    real_start = time.monotonic()
+    real_start = time.perf_counter()
 
     virtual_start = _core.current_time()
     for i in range(10):
@@ -320,10 +320,11 @@ async def test_mock_clock_autojump(mock_clock):
         assert virtual_start + 10 * i == _core.current_time()
         virtual_start = _core.current_time()
 
-    real_duration = time.monotonic() - real_start
+    real_duration = time.perf_counter() - real_start
     print(
-        "Slept {} seconds in {} seconds"
-        .format(10 * sum(range(10)), real_duration)
+        "Slept {} seconds in {} seconds".format(
+            10 * sum(range(10)), real_duration
+        )
     )
     assert real_duration < 1
 
@@ -378,9 +379,9 @@ def test_mock_clock_autojump_preset():
     # actually in use, and it gets picked up
     mock_clock = MockClock(autojump_threshold=0.1)
     mock_clock.autojump_threshold = 0.01
-    real_start = time.monotonic()
+    real_start = time.perf_counter()
     _core.run(sleep, 10000, clock=mock_clock)
-    assert time.monotonic() - real_start < 1
+    assert time.perf_counter() - real_start < 1
 
 
 async def test_mock_clock_autojump_0_and_wait_all_tasks_blocked(mock_clock):
@@ -468,8 +469,8 @@ async def test__UnboundeByteQueue():
         nursery.start_soon(getter, b"xyz")
         nursery.start_soon(putter, b"xyz")
 
-    # Two gets at the same time -> ResourceBusyError
-    with pytest.raises(_core.ResourceBusyError):
+    # Two gets at the same time -> BusyResourceError
+    with pytest.raises(_core.BusyResourceError):
         async with _core.open_nursery() as nursery:
             nursery.start_soon(getter, b"asdf")
             nursery.start_soon(getter, b"asdf")
@@ -523,7 +524,7 @@ async def test_MemorySendStream():
     with assert_checkpoints():
         assert await mss.get_data() == b"456"
 
-    # Call send_all twice at once; one should get ResourceBusyError and one
+    # Call send_all twice at once; one should get BusyResourceError and one
     # should succeed. But we can't let the error propagate, because it might
     # cause the other to be cancelled before it can finish doing its thing,
     # and we don't know which one will get the error.
@@ -533,7 +534,7 @@ async def test_MemorySendStream():
         nonlocal resource_busy_count
         try:
             await do_send_all(b"xxx")
-        except _core.ResourceBusyError:
+        except _core.BusyResourceError:
             resource_busy_count += 1
 
     async with _core.open_nursery() as nursery:
@@ -605,7 +606,7 @@ async def test_MemoryReceiveStream():
     with pytest.raises(TypeError):
         await do_receive_some(None)
 
-    with pytest.raises(_core.ResourceBusyError):
+    with pytest.raises(_core.BusyResourceError):
         async with _core.open_nursery() as nursery:
             nursery.start_soon(do_receive_some, 10)
             nursery.start_soon(do_receive_some, 10)
